@@ -298,12 +298,43 @@ static int addpeer(struct peer *pe0)
 	pe = calloc(1, sizeof(*pe));
 	if (pe == NULL)
 		err(1, "malloc failed");
+
 	*pe = *pe0;
+	if (pe0->pe_name)
+		pe->pe_name = strdup(pe0->pe_name);
+	if (pe0->pe_serv)
+		pe->pe_serv = strdup(pe0->pe_serv);
+
 	TAILQ_INSERT_TAIL(&pqueue, pe, pe_link);
 
 	return 0;
 }
 
+static void close_socket(struct peer *pe)
+{
+	for (size_t i = 0; i < pe->pe_socknum; i++) {
+		if (pe->pe_mode & 01000)
+			NOTE("Closing inet socket %s:%s", pe->pe_name ?: "*", pe->pe_serv);
+		socket_close(pe->pe_sock[i]);
+	}
+	pe->pe_socknum = 0;
+}
+
+static void delpeer(struct peer *pe)
+{
+	if (!pe)
+		return;
+
+	close_socket(pe);
+
+	if (pe->pe_name)
+		free(pe->pe_name);
+	if (pe->pe_serv)
+		free(pe->pe_serv);
+
+	free(pe);
+}
+
 static void sys_seqno_load(void)
 {
 	char buf[32], *str;
@@ -871,8 +902,14 @@ static int nslookup(const char *host, const char *service, struct addrinfo **ai)
 	if (!node || !node[0])
 		node = NULL;
 
-	/* Reset resolver cache and retry name lookup */
+	/*
+	 * Reset resolver cache and retry name lookup.  The use of
+	 * `_res` here seems to be the most portable way to adjust
+	 * the per-process timeout and retry.
+	 */
 	res_init();
+	_res.retrans = 1;
+	_res.retry = 1;
 
 	logit("nslookup '%s:%s'\n", node ?: "*", service);
 	memset(&hints, 0, sizeof(hints));
@@ -932,16 +969,6 @@ static int create_inet_socket(struct peer *pe)
 	return 0;
 }
 
-static void close_socket(struct peer *pe)
-{
-	for (size_t i = 0; i < pe->pe_socknum; i++) {
-		if (pe->pe_mode & 01000)
-			NOTE("Closing inet socket %s:%s", pe->pe_name ?: "*", pe->pe_serv);
-		socket_close(pe->pe_sock[i]);
-	}
-	pe->pe_socknum = 0;
-}
-
 void untty(void)
 {
 #ifdef HAVE_SETSID
@@ -2585,8 +2612,7 @@ void die(int signo)
 	 */
 	TAILQ_FOREACH_SAFE(pe, &pqueue, pe_link, next) {
 		TAILQ_REMOVE(&pqueue, pe, pe_link);
-		close_socket(pe);
-		free(pe);
+		delpeer(pe);
 	}
 
 	/*
@@ -2903,8 +2929,7 @@ static void init(void)
 			continue;
 
 		TAILQ_REMOVE(&pqueue, pe, pe_link);
-		close_socket(pe);
-		free(pe);
+		delpeer(pe);
 	}
 
 	Initialized = 1;
@@ -2991,8 +3016,26 @@ static void init(void)
 static void cflisten(char *ptr, void *arg)
 {
 	char *peer = ptr;
+	char *p;
 
-	ptr = strchr(peer, ':');
+	while (*peer && isspace(*peer))
+		++peer;
+
+	logit("cflisten[%s]\n", peer);
+
+	p = peer;
+	if (*p == '[') {
+		p++;
+
+		p = strchr(p, ']');
+		if (!p) {
+			ERR("Invalid IPv6 address in listen '%s', missing ']'", peer);
+			return;
+		}
+		*p++ = 0;
+	}
+
+	ptr = strchr(p, ':');
 	if (ptr)
 		*ptr++ = 0;
 	addpeer(&(struct peer) {
@@ -3218,8 +3261,19 @@ static struct filed *cfline(char *line)
 	switch (*p) {
 	case '@':
 		cfopts(p, f);
+		p++;
+		if (*p == '[') {
+			p++;
 
-		bp = strchr(++p, ':');
+			q = strchr(p, ']');
+			if (!q) {
+				ERR("Invalid IPv6 address in remote target, missing ']'");
+				break;
+			}
+			*q++ = 0;
+			bp = strchr(q, ':');
+		} else
+			bp = strchr(p, ':');
 		if (bp)
 			*bp++ = 0;
 		else
