@@ -226,8 +226,8 @@
  */
 struct peer {
 	TAILQ_ENTRY(peer)	pe_link;
-	const char	*pe_name;
-	const char	*pe_serv;
+	char		*pe_name;
+	char		*pe_serv;
 	int		 pe_mark;
 	mode_t		 pe_mode;
 	int		 pe_sock[16];
